package com.xkrs.controller;

import com.xkrs.dao.DataDictDao;
import com.xkrs.encapsulation.PromptMessageEnum;
import com.xkrs.model.entity.DataDict;
import com.xkrs.model.qo.DataDictQo;
import com.xkrs.model.qo.DataDictUpdateQo;
import com.xkrs.service.DataDictService;
import com.xkrs.util.DataDictQuery;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.transaction.Transactional;
import java.util.List;
import java.util.Locale;
import java.util.Optional;

import static com.xkrs.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * @Author: XinYi Song
 * @Date: 2022/1/19 10:54
 */
@RestController
public class DataDictController {

    @Resource
    private DataDictService dataDictService;

    @Resource
    private DataDictDao dataDictDao;

    @Resource
    private DataDictQuery dataDictQuery;

    /**
     * 添加字典变量数据
     *
     * @param dataDictQo
     * @return
     */
    @PostMapping("/insertDataDict")
    public String insertDataDict(@RequestBody DataDictQo dataDictQo) {
        return dataDictService.insertDataDict(dataDictQo);
    }

    /**
     * 动态多条件查询字典信息
     *
     * @param inspectionItemName
     * @param inspectionItemCode
     * @return
     */
    @GetMapping("/selectDataDict")
    public String selectDataDict(@RequestParam("inspectionItemName") String inspectionItemName,
                                 @RequestParam("inspectionItemCode") String inspectionItemCode) {
        Locale locale = LocaleContextHolder.getLocale();
        List<DataDict> dataDict = dataDictQuery.selectDataDict(inspectionItemName, inspectionItemCode);
        if (dataDict == null || dataDict.size() == 0) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "暂时还没有该型号类型的字典信息！", locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, dataDict, locale);
    }

    /**
     * 根据id查询字典信息，用于数据回显，方便进行修改操作
     *
     * @param id
     * @return
     */
    @GetMapping("/selectDataDictById")
    public String selectDataDictById(@RequestParam("id") Integer id) {
        Locale locale = LocaleContextHolder.getLocale();
        Optional<DataDict> byId = dataDictDao.findById(id);
        if (byId.isEmpty()) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "暂时还没有该型号类型的字典信息！", locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, byId.get(), locale);
    }

    /**
     * 根据id修改字典信息
     *
     * @param dataDictUpdateQo
     * @return
     */
    @PostMapping("/updateDict")
    @Transactional(rollbackOn = Exception.class)
    public String updateDict(@RequestBody DataDictUpdateQo dataDictUpdateQo) {
        Locale locale = LocaleContextHolder.getLocale();
        dataDictDao.updateDict(dataDictUpdateQo.getId(), dataDictUpdateQo.getInspectionItemName());
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "修改成功！", locale);
    }
}
